@@ -62,11 +62,13 @@ method, and return the instance.
 import tkinter
 import tkinter.filedialog
 
-from .exceptionhandler import ExceptionHandler, FOCUS_ERROR, DESTROY_ERROR
+from solentware_bind.gui.bindings import Bindings
+from solentware_bind.gui.exceptionhandler import FOCUS_ERROR, DESTROY_ERROR
+
 from . import textreadonly
 
 
-class Dialogue(ExceptionHandler):
+class Dialogue(Bindings):
     """Base class for non-modal dialogues which use the event loop for parent.
 
     parent - report's parent object (note this is not a tkinter widget).
@@ -119,8 +121,8 @@ class Dialogue(ExceptionHandler):
 
     def __init__(
         self,
-        parent,
-        title,
+        parent=None,
+        title=None,
         text=None,
         action_titles=None,
         buttons=None,
@@ -301,7 +303,7 @@ class Dialogue(ExceptionHandler):
                 width = self.body.cget("width")
                 lines = text.splitlines()
                 linecount = len(lines)
-                maxlinelength = max(len(l) for l in lines)
+                maxlinelength = max(len(line) for line in lines)
                 if linecount > height or maxlinelength > width:
                     forcescroll = True
                     if maxlinelength > width:
@@ -396,9 +398,9 @@ class ModalDialogueGo(Dialogue):
     **kargs - passed to superclass as **kargs argument.
     """
 
-    def __init__(self, *args, geometry=True, **kargs):
+    def __init__(self, geometry=True, **kargs):
         """Extend and note widget with focus on opening dialogue."""
-        super().__init__(*args, geometry=geometry, **kargs)
+        super().__init__(geometry=geometry, **kargs)
         self.restore_focus = self.root.focus_get()
 
     # Follow example in tkinter.simpledialog.SimpleDialog class.
@@ -428,6 +430,7 @@ class ModalDialogueGo(Dialogue):
             # application destroyed while confirm dialogue exists.
             if str(error) != FOCUS_ERROR:
                 raise
+        super().__del__()
 
     def button_on_attr(self, action):
         """Return default event handler for button name 'a'."""
@@ -459,9 +462,9 @@ class ModalDialogue(Dialogue):
     **kargs - passed to superclass as **kargs argument.
     """
 
-    def __init__(self, *args, **kargs):
+    def __init__(self, **kargs):
         """Extend and note widget with focus on opening dialogue."""
-        super().__init__(*args, **kargs)
+        super().__init__(**kargs)
         self.restore_focus = self.root.focus_get()
 
         # Emulate reports.AppSysDialogueBase
@@ -479,6 +482,7 @@ class ModalDialogue(Dialogue):
             # application destroyed while confirm dialogue exists
             if str(error) != FOCUS_ERROR:
                 raise
+        super().__del__()
 
     def widget_transient(self, widget, master):
         """Mark the widget transient.
@@ -511,9 +515,9 @@ class Report(Dialogue):
 
     buttons = "Save", "Close"
 
-    def __init__(self, *args, interval=5000, buttons=None, **kargs):
+    def __init__(self, interval=5000, buttons=None, **kargs):
         """Extend superclass to ignore redundant arguments."""
-        super().__init__(*args, buttons=self.buttons, **kargs)
+        super().__init__(buttons=self.buttons, **kargs)
 
     def append(self, text):
         """Override to append task to queue of tasks to be done in main thread.
@@ -574,9 +578,7 @@ class Report(Dialogue):
             return
         outfile = open(dlg, mode="wb")
         try:
-            outfile.write(
-                self.body.get("1.0", tkinter.END).encode("utf8")
-            )
+            outfile.write(self.body.get("1.0", tkinter.END).encode("utf8"))
         finally:
             outfile.close()
 
@@ -588,7 +590,7 @@ def show_report(parent, title, **kargs):
     title - passed to Report as title argument.
     **kargs - passed to Report as **kargs argument.
     """
-    return Report(parent, title, **kargs)
+    return Report(parent=parent, title=title, **kargs)
 
 
 # ModalConfirm is the replacement for the reports.AppSysConfirm class because
@@ -603,9 +605,9 @@ class ModalConfirm(ModalDialogue):
 
     buttons = "Ok", "Cancel"
 
-    def __init__(self, *args, buttons=None, **kargs):
+    def __init__(self, buttons=None, **kargs):
         """Extend superclass to provide Ok and Cancel buttons."""
-        super().__init__(*args, buttons=self.buttons, **kargs)
+        super().__init__(buttons=self.buttons, **kargs)
 
 
 class ModalConfirmGo(ModalDialogueGo):
@@ -618,9 +620,9 @@ class ModalConfirmGo(ModalDialogueGo):
 
     buttons = "Ok", "Cancel"
 
-    def __init__(self, *args, buttons=None, **kargs):
+    def __init__(self, buttons=None, **kargs):
         """Extend superclass to provide Ok and Cancel buttons."""
-        super().__init__(*args, buttons=self.buttons, **kargs)
+        super().__init__(buttons=self.buttons, **kargs)
 
 
 def show_modal_confirm(parent, title, **kargs):
@@ -630,7 +632,7 @@ def show_modal_confirm(parent, title, **kargs):
     title - passed to ModalConfirmGo as title argument.
     **kargs - passed to ModalConfirmGo as **kargs argument.
     """
-    widget = ModalConfirmGo(parent, title, **kargs)
+    widget = ModalConfirmGo(parent=parent, title=title, **kargs)
     widget.go()
     return widget
 
@@ -647,9 +649,9 @@ class ModalInformation(ModalDialogue):
 
     buttons = ("Ok",)
 
-    def __init__(self, *args, buttons=None, **kargs):
+    def __init__(self, buttons=None, **kargs):
         """Extend superclass to provide Ok button."""
-        super().__init__(*args, buttons=self.buttons, **kargs)
+        super().__init__(buttons=self.buttons, **kargs)
 
 
 class ModalInformationGo(ModalDialogueGo):
@@ -662,9 +664,9 @@ class ModalInformationGo(ModalDialogueGo):
 
     buttons = ("Ok",)
 
-    def __init__(self, *args, buttons=None, **kargs):
+    def __init__(self, buttons=None, **kargs):
         """Extend superclass to provide Ok button."""
-        super().__init__(*args, buttons=self.buttons, **kargs)
+        super().__init__(buttons=self.buttons, **kargs)
 
 
 def show_modal_information(parent, title, **kargs):
@@ -674,7 +676,7 @@ def show_modal_information(parent, title, **kargs):
     title - passed to ModalInformationGo as title argument.
     **kargs - passed to ModalInformationGo as **kargs argument.
     """
-    widget = ModalInformationGo(parent, title, **kargs)
+    widget = ModalInformationGo(parent=parent, title=title, **kargs)
     widget.go()
     return widget
 
@@ -712,7 +714,7 @@ class _Entry:
 
     buttons = "Ok", "Cancel"
 
-    def __init__(self, *args, buttons=None, scroll=False, body=None, **kargs):
+    def __init__(self, buttons=None, scroll=False, body=None, **kargs):
         """Extend to provide Ok and Cancel buttons and dialogue body."""
         if body is None:
             body = (("", "", None, False),)
@@ -721,14 +723,15 @@ class _Entry:
         self.entries = {}
         self.result = None
         super().__init__(
-            *args, buttons=self.buttons, scroll=False, body=body, **kargs
+            buttons=self.buttons, scroll=False, body=body, **kargs
         )
 
     def __del__(self):
         """Restore focus to widget with focus before dialogue started."""
         self.entries = None
         self.result = None
-        super().__del__()
+        if hasattr(super(), "__del__"):
+            super().__del__()
 
     def append(self, text):
         """Override, do nothing."""
@@ -1063,8 +1066,8 @@ if __name__ == "__main__":
             """Handle Dialogue button events."""
             del event
             Dialogue(
-                mainframe,
-                "Dialogue",
+                parent=mainframe,
+                title="Dialogue",
                 text="Message longer than width",
                 buttons=("Ok",),
                 side=tkinter.TOP,
@@ -1078,8 +1081,8 @@ if __name__ == "__main__":
             """Handle ModalDialogueGo button events."""
             del event
             ModalDialogueGo(
-                mainframe,
-                "ModalDialogueGo",
+                parent=mainframe,
+                title="ModalDialogueGo",
                 text="Message longer than width",
                 buttons=("Ok",),
                 side=tkinter.TOP,
@@ -1093,8 +1096,8 @@ if __name__ == "__main__":
             """Handle ModalDialogue button events."""
             del event
             ModalDialogue(
-                mainframe,
-                "ModalDialogue",
+                parent=mainframe,
+                title="ModalDialogue",
                 text="Message longer than width",
                 buttons=("Ok",),
                 side=tkinter.TOP,
@@ -1108,8 +1111,8 @@ if __name__ == "__main__":
             """Handle ModalConfirmGo button events."""
             del event
             ModalConfirmGo(
-                mainframe,
-                "ModalConfirmGo",
+                parent=mainframe,
+                title="ModalConfirmGo",
                 text="Message longer than width",
                 side=tkinter.TOP,
                 scroll=False,
@@ -1121,8 +1124,8 @@ if __name__ == "__main__":
             """Handle ModalConfirm button events."""
             del event
             ModalConfirm(
-                mainframe,
-                "ModalConfirm",
+                parent=mainframe,
+                title="ModalConfirm",
                 text="Message longer than width",
                 side=tkinter.TOP,
                 scroll=False,
@@ -1134,8 +1137,8 @@ if __name__ == "__main__":
             """Handle ModalInformationGo button events."""
             del event
             ModalInformationGo(
-                mainframe,
-                "ModalInformationGo",
+                parent=mainframe,
+                title="ModalInformationGo",
                 text="Message longer than width",
                 side=tkinter.TOP,
                 scroll=False,
@@ -1148,8 +1151,8 @@ if __name__ == "__main__":
             """Handle ModalInformation button events."""
             del event
             ModalInformation(
-                mainframe,
-                "ModalInformation",
+                parent=mainframe,
+                title="ModalInformation",
                 text="Message longer than width",
                 side=tkinter.TOP,
                 scroll=False,
@@ -1161,19 +1164,19 @@ if __name__ == "__main__":
         def on_modalentrygo_1(self, event=None):
             """Handle ModalEntryGo button events."""
             del event
-            ModalEntryGo(mainframe, "ModalEntryGo").go()
+            ModalEntryGo(parent=mainframe, title="ModalEntryGo").go()
 
         def on_modalentry_1(self, event=None):
             """Handle ModalEntry button events."""
             del event
-            ModalEntry(mainframe, "ModalEntry").root.mainloop()
+            ModalEntry(parent=mainframe, title="ModalEntry").root.mainloop()
 
         def on_modalentrygo(self, event=None):
             """Handle ModalEntryGo button events."""
             del event
             ModalEntryGo(
-                mainframe,
-                "ModalEntryGo",
+                parent=mainframe,
+                title="ModalEntryGo",
                 body=(
                     ("URL", "", None, False),
                     ("Password", "mypw", "*", True),
@@ -1184,8 +1187,8 @@ if __name__ == "__main__":
             """Handle ModalEntry button events."""
             del event
             ModalEntry(
-                mainframe,
-                "ModalEntry",
+                parent=mainframe,
+                title="ModalEntry",
                 body=(
                     ("URL", "", None, False),
                     ("Password", "mypw", "*", True),
@@ -1196,8 +1199,8 @@ if __name__ == "__main__":
             """Handle ModalEntryApplyGo button events."""
             del event
             ModalEntryApplyGo(
-                mainframe,
-                "ModalEntryApplyGo",
+                parent=mainframe,
+                title="ModalEntryApplyGo",
                 body=(
                     ("URL", "", None, False),
                     ("Password", "mypw", "*", True),
@@ -1208,8 +1211,8 @@ if __name__ == "__main__":
             """Handle ModalEntryApply button events."""
             del event
             ModalEntryApply(
-                mainframe,
-                "ModalEntryApply",
+                parent=mainframe,
+                title="ModalEntryApply",
                 body=(
                     ("URL", "", None, False),
                     ("Password", "mypw", "*", True),
@@ -1220,7 +1223,7 @@ if __name__ == "__main__":
             """Handle Report button events."""
             del event
             Report(
-                mainframe, "Report", text="Some report text"
+                parent=mainframe, title="Report", text="Some report text"
             ).root.mainloop()
 
         # self.parent to quit application.
@@ -1230,7 +1233,7 @@ if __name__ == "__main__":
             del event
             self.parent.winfo_toplevel().destroy()
 
-    mainframe = MainFrame(tkinter.Tk(), height=300, width=400)
+    mainframe = MainFrame(master=tkinter.Tk(), height=300, width=400)
     mainframe.pack()
     mainframe.winfo_toplevel().wm_title("Main Window")
 
@@ -1238,8 +1241,8 @@ if __name__ == "__main__":
     mainframe.wait_visibility()
 
     MainDialogue(
-        mainframe,
-        "Dialogues",
+        parent=mainframe,
+        title="Dialogues",
         text="".join(
             (
                 "Try the dialogues associated with each button.\n\nThe *Go ",
