@@ -14,24 +14,26 @@ and behaviour is undefined if the solentware_grid package is not available.
 
 import tkinter
 
-from .exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
 
 class AppSysPanelError(Exception):
     """Exception for AppSysPanel class."""
 
 
-class AppSysPanelButton(ExceptionHandler):
+class AppSysPanelButton(Bindings):
     """Put a tkinter.Button in the frame of a parent reserved for buttons."""
 
-    def __init__(self, parent, identity, switchpanel, cnf=None, **kargs):
+    def __init__(
+        self, parent=None, identity=None, switchpanel=None, cnf=None, **kargs
+    ):
         """Create page action button.
 
         parent - parent AppSysPanel.
         identity - arbitrary identity number for button.
         switchpanel - if True button is allowed to change page in notebook.
         cnf - passed to tkinter.Button() as cnf argument, default {}.
-        **kargs - passed to tkinter.Button() as **kargs.
+        **kargs - passed to super().__init__() call as **kargs argument.
 
         The identity must be unique within the application for buttons.  It
         is used to keep track of context while navigating tabs.
@@ -40,17 +42,14 @@ class AppSysPanelButton(ExceptionHandler):
         self.parent = parent
         self.switchpanel = switchpanel
         self.identity = identity
-        self.command = kargs.get("command")
-        try:
-            del kargs["command"]
-        except:
-            pass
+        self.command = cnf.get("command")
 
+        # When converted to tkinter.ttk.Button cnf will be passed as **cnf.
         self.button = tkinter.Button(
             master=parent.get_buttons_frame(),
             cnf={} if cnf is None else cnf,
-            **kargs
         )
+        super().__init__(**kargs)
 
         self.obeycontextswitch = True
 
@@ -182,7 +181,7 @@ class AppSysPanelButton(ExceptionHandler):
             # pass
 
 
-class AppSysPanel(ExceptionHandler):
+class AppSysPanel(Bindings):
     """This is the base class for pages in a notebook style user interface.
 
     It provides the main frame of a page.  A frame for buttons that invoke
@@ -191,19 +190,22 @@ class AppSysPanel(ExceptionHandler):
 
     """
 
-    def __init__(self, parent, cnf=None, **kargs):
+    def __init__(self, parent=None, cnf=None, **kargs):
         """Define basic structure of a page of a notebook style application.
 
-        parent - AppSysFrame instance that owns this AppSysPanel instance
-        cnf - passed to main tkinter.Frame() call as cnf argument, default {}
-        **kargs - passed to main tkinter.Frame() call as **kargs argument
+        parent - AppSysFrame instance that owns this AppSysPanel instance.
+        cnf - passed to main tkinter.Frame() call as cnf argument, default {}.
+        **kargs - passed to super().__init__() call as **kargs argument.
 
         Subclasses define the content of the page and the action buttons.
 
         """
-        self.panel = tkinter.Frame(
-            master=parent.get_widget(), cnf={} if cnf is None else cnf, **kargs
-        )
+        if cnf is None:
+            cnf = {}
+
+        # When converted to tkinter.ttk.Frame cnf will be passed as **cnf.
+        self.panel = tkinter.Frame(master=parent.get_widget(), cnf=cnf)
+
         self.buttons_frame = tkinter.Frame(master=self.panel)
         self._give_focus_widget = None
         self.buttons_frame.pack(side=tkinter.BOTTOM, fill=tkinter.X)
@@ -214,7 +216,7 @@ class AppSysPanel(ExceptionHandler):
         self.button_order = []
         self.buttons = {}
         self.describe_buttons()
-        super().__init__()
+        super().__init__(**kargs)
 
     def close(self):
         """Raise AppSysPanelError('close not implemented') error.
@@ -233,13 +235,15 @@ class AppSysPanel(ExceptionHandler):
         for i, button in enumerate(self.button_order):
             if button not in self.buttons:
                 self.buttons[button] = AppSysPanelButton(
-                    self,
-                    button,
-                    definitions[button][2],
-                    text=definitions[button][0],
-                    underline=definitions[button][3],
-                    command=self.try_command(
-                        definitions[button][4], self.buttons_frame
+                    parent=self,
+                    identity=button,
+                    switchpanel=definitions[button][2],
+                    cnf=dict(
+                        text=definitions[button][0],
+                        underline=definitions[button][3],
+                        command=self.try_command(
+                            definitions[button][4], self.buttons_frame
+                        ),
                     ),
                 )
             self.buttons[button].raise_action_button()
@@ -435,6 +439,7 @@ class AppSysPanel(ExceptionHandler):
     def __del__(self):
         """Call the close() method."""
         self.close()
+        super().__del__()
 
 
 class PlainPanel(AppSysPanel):
@@ -443,8 +448,8 @@ class PlainPanel(AppSysPanel):
     def make_grids(self, gridarguments):
         """Raise exception because *grid* classes are not supported.
 
-        Subclasses can use classes from solentware_grid, but must be responsible
-        for managing them.
+        Subclasses can use classes from solentware_grid, but must be
+        responsible for managing them.
         """
         raise AppSysPanelError("solentware_grid *grid* classes not supported")
 
@@ -462,15 +467,11 @@ class PanelWithGrids(AppSysPanel):
     Subclasses of PanelWithGrids may arrange grids and selectors differently.
     """
 
-    def __init__(
-        self, parent, useselector=True, gridhorizontal=True, cnf=None, **kargs
-    ):
+    def __init__(self, useselector=True, gridhorizontal=True, **kargs):
         """Create panel to which grids and selectors may be added.
 
-        parent - passed to superclass as parent argument.
         useselector - if True a selector is provided for each grid.
         gridhorizontal - if True grids are arranged horizontally.
-        cnf - passed to superclass as cnf argument, default {}.
         **kargs - passed to superclass as **kargs argument.
 
         Selectors are either present for all grids or absent for all grids.
@@ -478,9 +479,7 @@ class PanelWithGrids(AppSysPanel):
         Grids are arranged horizontally or vertically.
 
         """
-        super().__init__(
-            parent=parent, cnf={} if cnf is None else cnf, **kargs
-        )
+        super().__init__(**kargs)
         self.useselector = useselector is True
         self.gridhorizontal = gridhorizontal is True
         self.gridselector = dict()
@@ -517,7 +516,7 @@ class PanelWithGrids(AppSysPanel):
         The gridmaster argument is usually self.frame.
         """
         gridframe = grid(
-            gridmaster,
+            parent=gridmaster,
             selecthintlabel=selectlabel,
             appsyspanel=self,
             receivefocuskey=gridfocuskey,
@@ -578,16 +577,15 @@ class PanelWithGrids(AppSysPanel):
 class PanelGridSelector(PanelWithGrids):
     """Display data grids in equal share of space next to their selectors."""
 
-    def __init__(self, parent, **kargs):
+    def __init__(self, **kargs):
         """Delegate to superclass then create Tkinter.Frame widget.
 
-        parent - passed to superclass as parent argument.
         **kargs - passed to superclass as **kargs argument.
 
         The extra widget in the hierarchy adjusts the behaviour of the
         widgets when the application is resized.
         """
-        super().__init__(parent, **kargs)
+        super().__init__(**kargs)
 
         self.gridpane = tkinter.Frame(master=self.get_widget())
         self.gridpane.pack(
@@ -679,18 +677,17 @@ class PanelGridSelector(PanelWithGrids):
 class PanelGridSelectorBar(PanelWithGrids):
     """Display data grids in equal share of space with selectors in own row."""
 
-    def __init__(self, parent, **kargs):
+    def __init__(self, **kargs):
         """Delegate to superclass then create Tkinter.Frame widget.
 
-        parent - passed to superclass as parent argument.
         **kargs - passed to superclass as **kargs argument.
 
         The extra widget in the hierarchy adjusts the behaviour of the
         widgets when the application is resized.
         """
-        super().__init__(parent, **kargs)
+        super().__init__(**kargs)
 
-        self.gridpane = tkinter.Frame(master=self.get_widget())
+        self.gridpane = tkinter.Frame(master=self.get_widget(), cnf={})
         self.gridpane.pack(
             side=tkinter.TOP, expand=tkinter.TRUE, fill=tkinter.BOTH
         )
@@ -776,16 +773,15 @@ class PanelGridSelectorBar(PanelWithGrids):
 class PanelGridSelectorShared(PanelWithGrids):
     """Display data grids in equal share of space with a shared selector."""
 
-    def __init__(self, parent, **kargs):
+    def __init__(self, **kargs):
         """Delegate to superclass then create Tkinter.Frame widget.
 
-        parent - passed to superclass as parent argument.
         **kargs - passed to superclass as **kargs argument.
 
         The extra widget in the hierarchy adjusts the behaviour of the
         widgets when the application is resized.
         """
-        super().__init__(parent, **kargs)
+        super().__init__(**kargs)
 
         self.gridpane = tkinter.Frame(master=self.get_widget())
         self.gridpane.pack(
@@ -894,16 +890,15 @@ class PanelGridSelectorShared(PanelWithGrids):
 class PanedPanelGridSelector(PanelWithGrids):
     """Display data grids in adjustable space next to their selectors."""
 
-    def __init__(self, parent, **kargs):
+    def __init__(self, **kargs):
         """Delegate to superclass then create Tkinter.PanedWindow widget.
 
-        parent - passed to superclass as parent argument.
         **kargs - passed to superclass as **kargs argument.
 
         The extra widget in the hierarchy adjusts the behaviour of the
         widgets when the application is resized.
         """
-        super().__init__(parent, **kargs)
+        super().__init__(**kargs)
 
         if self.gridhorizontal:
             orient = tkinter.HORIZONTAL
@@ -979,16 +974,15 @@ class PanedPanelGridSelector(PanelWithGrids):
 class PanedPanelGridSelectorBar(PanelWithGrids):
     """Display data grids in adjustable space with selectors in own row."""
 
-    def __init__(self, parent, **kargs):
+    def __init__(self, **kargs):
         """Delegate to superclass then create Tkinter.PanedWindow widget.
 
-        parent - passed to superclass as parent argument.
         **kargs - passed to superclass as **kargs argument.
 
         The extra widget in the hierarchy adjusts the behaviour of the
         widgets when the application is resized.
         """
-        super().__init__(parent, **kargs)
+        super().__init__(**kargs)
 
         if self.gridhorizontal:
             orient = tkinter.HORIZONTAL
@@ -1067,16 +1061,15 @@ class PanedPanelGridSelectorBar(PanelWithGrids):
 class PanedPanelGridSelectorShared(PanelWithGrids):
     """Display data grids in adjustable space with a shared selector."""
 
-    def __init__(self, parent, **kargs):
+    def __init__(self, **kargs):
         """Delegate to superclass then create Tkinter.PanedWindow widget.
 
-        parent - passed to superclass as parent argument.
         **kargs - passed to superclass as **kargs argument.
 
         The extra widget in the hierarchy adjusts the behaviour of the
         widgets when the application is resized.
         """
-        super().__init__(parent, **kargs)
+        super().__init__(**kargs)
 
         if self.gridhorizontal:
             orient = tkinter.HORIZONTAL
